@@ -2,10 +2,10 @@ function _aws_cdk_aws_lambda_destinations_LambdaDestinationOptions(p) {
 }
 function _aws_cdk_aws_lambda_destinations_EventBridgeDestination(p) {
 }
-function _aws_cdk_aws_lambda_destinations_SnsDestination(p) {
-}
 function _aws_cdk_aws_lambda_destinations_SqsDestination(p) {
 }
+function _aws_cdk_aws_lambda_destinations_SnsDestination(p) {
+}
 function _aws_cdk_aws_lambda_destinations_LambdaDestination(p) {
 }
 function print(name, deprecationMessage) {
@@ -23,5 +23,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_lambda_destinations_LambdaDestinationOptions, _aws_cdk_aws_lambda_destinations_EventBridgeDestination, _aws_cdk_aws_lambda_destinations_SnsDestination, _aws_cdk_aws_lambda_destinations_SqsDestination, _aws_cdk_aws_lambda_destinations_LambdaDestination };
+module.exports = { print, _aws_cdk_aws_lambda_destinations_LambdaDestinationOptions, _aws_cdk_aws_lambda_destinations_EventBridgeDestination, _aws_cdk_aws_lambda_destinations_SqsDestination, _aws_cdk_aws_lambda_destinations_SnsDestination, _aws_cdk_aws_lambda_destinations_LambdaDestination };
 module.exports.DeprecationError = DeprecationError;
